# Inmarsat FieldEdge Utilities

Inmarsat FieldEdge project supports *Internet of Things* (**IoT**) using
satellite communications technology.

This library available on **PyPI** provides:

* A common **`logger`** format and wrapping file facility.
* A simplified **`mqtt`** client that automatically connects
(to a `fieldedge-broker`).
* Helper functions for managing files and **`path`** on different OS.
* An interface for **`hostpipe`** service interacting via a logfile.

[Docmentation](https://inmarsat-enterprise.github.io/fieldedge-utilities/)
